CombRef

Enum CombRef 

pub enum CombRef {
Show 19 variants Rule(RuleId), Seq(SeqId), Choice(ChoiceId), ZeroOrMore(LoopId), OneOrMore(LoopId), Optional(OptId), Literal(LitId), CharClass(CharClass), CharRange(char, char), Char(char), AnyChar, Capture(CapId), NotFollowedBy(LookId), FollowedBy(LookId), Skip(SkipId), SeparatedBy(SepById), Pratt(PrattId), Mapped(MapId), Memoize(MemoId),
}
Reference to a combinator by its type and index. Used in generated static tables to reference child combinators.

Variants



Rule(RuleId)

Reference to a rule



Seq(SeqId)

Reference to a sequence



Choice(ChoiceId)

Reference to a choice



ZeroOrMore(LoopId)

Reference to zero-or-more loop



OneOrMore(LoopId)

Reference to one-or-more loop



Optional(OptId)

Reference to optional



Literal(LitId)

Reference to a literal



CharClass(CharClass)

Match a character class



CharRange(char, char)

Match a character range



Char(char)

Match a single specific character



AnyChar

Match any character



Capture(CapId)

Reference to a capture



NotFollowedBy(LookId)

Reference to not-followed-by lookahead



FollowedBy(LookId)

Reference to followed-by lookahead



Skip(SkipId)

Reference to a skip



SeparatedBy(SepById)

Reference to separated-by



Pratt(PrattId)

Reference to Pratt expression parser



Mapped(MapId)

Reference to a mapped combinator



Memoize(MemoId)

Reference to a memoized combinator